@@ -33,11 +33,19 @@ class Interface(QWidget):
         for replay in replays:
             self.replay_statistics_precalculated[replay] = (None, None, None, None)
 
-        # and here's the thread which will actually start those calculations
-        cg_statistics_worked = Thread(target=self.calculate_cg_statistics)
-        # allow users to quit before we're done calculating
-        cg_statistics_worked.daemon = True
-        cg_statistics_worked.start()
+        # only precalculate statistics if we're visualizing 5 or fewer replays.
+        # Otherwise, the thread is too overworked and lags the main draw thread
+        # significantly until all statistics are precalculated.
+        # TODO This may be resolved properly by using a QThread with a low
+        # priority instead, so as not to starve the draw thread. We should be
+        # using QThreads instead of python threads regardless.
+
+        if len(replays) <= 5:
+            # and here's the thread which will actually start those calculations
+            cg_statistics_worked = Thread(target=self.calculate_cg_statistics)
+            # allow users to quit before we're done calculating
+            cg_statistics_worked.daemon = True
+            cg_statistics_worked.start()
 
         # create our own library in a temp dir if one wasn't passed
         if not self.library:
@@ -66,7 +74,7 @@ class Interface(QWidget):
         # if the renderer wants to pause itself (eg when the playback hits the
         # end of the replay), we kick it back to us (the `Interface`) so we can
         # also update the pause button's state.
-        self.renderer.pause_signal.connect(self.pause)
+        self.renderer.pause_signal.connect(self.toggle_pause)
 
         # we want to give `VisualizerControls` the union of all the replay's
         # mods
@@ -75,7 +83,7 @@ class Interface(QWidget):
             mods += replay.mods
 
         self.controls = VisualizerControls(start_speed, mods, replays)
-        self.controls.pause_button.clicked.connect(self.pause)
+        self.controls.pause_button.clicked.connect(self.toggle_pause)
         self.controls.play_reverse_button.clicked.connect(self.play_reverse)
         self.controls.play_normal_button.clicked.connect(self.play_normal)
         self.controls.next_frame_button.clicked.connect(lambda: self.change_frame(reverse=False))
@@ -107,17 +115,19 @@ class Interface(QWidget):
         self.setLayout(layout)
 
     def play_normal(self):
-        self.renderer.resume()
-        self.controls.set_paused_state(False)
+        self.unpause()
         self.renderer.play_direction = 1
         self.update_speed(abs(self.renderer.clock.current_speed))
 
     def update_slider(self, value):
         self.controls.time_slider.setValue(value)
 
+    def change_by(self, delta):
+        self.pause()
+        self.renderer.seek_to(self.renderer.clock.time_counter + delta)
+
     def play_reverse(self):
-        self.renderer.resume()
-        self.controls.set_paused_state(False)
+        self.unpause()
         self.renderer.play_direction = -1
         self.update_speed(abs(self.renderer.clock.current_speed))
 
@@ -125,25 +135,20 @@ class Interface(QWidget):
         self.renderer.clock.change_speed(speed * self.renderer.play_direction)
 
     def change_frame(self, reverse):
-        # only change pause state if we're not paused, this way we don't unpause
-        # when changing frames
-        if not self.renderer.paused:
-            self.pause()
+        self.pause()
         self.renderer.search_nearest_frame(reverse=reverse)
 
-    def pause(self):
+    def toggle_pause(self):
         if self.renderer.paused:
-            self.controls.set_paused_state(False)
-            self.renderer.resume()
+            self.unpause()
         else:
-            self.controls.set_paused_state(True)
-            self.renderer.pause()
+            self.pause()
 
-    def force_pause(self):
+    def pause(self):
         self.controls.set_paused_state(True)
         self.renderer.pause()
 
-    def force_unpause(self):
+    def unpause(self):
         self.controls.set_paused_state(False)
         self.renderer.resume()
 
@@ -211,7 +216,7 @@ class Interface(QWidget):
         self.replay_info_cache[replay] = replay_info
 
     def seek_to(self, time):
-        self.force_pause()
+        self.pause()
         self.renderer.seek_to(time)
 
     def calculate_cg_statistics(self):
