@@ -33,27 +33,21 @@ class Visualizer(QMainWindow):
             speeds, start_speed, paint_info, statistic_functions, snaps_args)
         self.setCentralWidget(self.interface)
 
-        QShortcut(QKeySequence(Qt.Key_Space), self, self.interface.pause)
-        QShortcut(QKeySequence(Qt.Key_Right), self, \
-            lambda: self.interface.change_frame(reverse=False))
-        QShortcut(QKeySequence(Qt.Key_Left), self, \
-            lambda: self.interface.change_frame(reverse=True))
-        QShortcut(QKeySequence(Qt.CTRL + Qt.Key_Right), self, \
-            self.interface.play_normal)
-        QShortcut(QKeySequence(Qt.CTRL + Qt.Key_Left), self, \
-            self.interface.play_reverse)
-        QShortcut(QKeySequence(Qt.Key_Up), self, \
-            self.interface.increase_speed)
-        QShortcut(QKeySequence(Qt.Key_Down), self, \
-            self.interface.lower_speed)
-        QShortcut(QKeySequence(Qt.CTRL + Qt.Key_F11), self, \
-            lambda: self.interface.renderer.toggle_frametime)
+        QShortcut(Qt.Key_Space, self, self.interface.toggle_pause)
+        QShortcut(Qt.Key_Right, self, lambda: self.interface.change_frame(reverse=False))
+        QShortcut(Qt.Key_Left, self, lambda: self.interface.change_frame(reverse=True))
+        QShortcut(Qt.CTRL + Qt.Key_Right, self, self.interface.play_normal)
+        QShortcut(Qt.CTRL + Qt.Key_Left, self, self.interface.play_reverse)
+        QShortcut(Qt.Key_Up, self, self.interface.increase_speed)
+        QShortcut(Qt.Key_Down, self, self.interface.lower_speed)
+        QShortcut(Qt.CTRL + Qt.Key_F11, self, self.interface.renderer.toggle_frametime)
         QShortcut(QKeySequence.FullScreen, self, self.toggle_fullscreen)
-        QShortcut(QKeySequence(Qt.Key_F), self, self.toggle_fullscreen)
-        QShortcut(QKeySequence(Qt.ALT + Qt.Key_Return), self, \
-            self.toggle_fullscreen)
-        QShortcut(QKeySequence(Qt.Key_Escape), self, self.exit_fullscreen)
+        QShortcut(Qt.Key_F, self, self.toggle_fullscreen)
+        QShortcut(Qt.ALT + Qt.Key_Return, self, self.toggle_fullscreen)
+        QShortcut(Qt.Key_Escape, self, self.exit_fullscreen)
         QShortcut(QKeySequence.Paste, self, self.seek_to_paste_contents)
+        QShortcut(Qt.Key_Period, self, lambda: self.interface.change_by(1))
+        QShortcut(Qt.Key_Comma, self, lambda: self.interface.change_by(-1))
 
         # ugly hack to make the window 20% larger, we can't change gameplay
         # height because that's baked in as the osu! gameplay height and is
@@ -93,18 +87,22 @@ class Visualizer(QMainWindow):
     def seek_to(self, timestamp):
         self.interface.renderer.seek_to(timestamp)
 
+    def toggle_pause(self):
+        self.interface.toggle_pause()
+
     def pause(self):
         self.interface.pause()
 
-    def force_pause(self):
-        self.interface.force_pause()
-
-    def force_unpause(self):
-        self.interface.force_unpause()
+    def unpause(self):
+        self.interface.unpause()
 
     def save_as_image(self):
         return self.grab().toImage()
 
+    # TODO remove in circlevis 2.0.0
+    force_pause = pause
+    force_unpause = unpause
+
 class VisualizerApp(QApplication):
     """
     ``speeds`` must contain ``start_speed``, ``1``, ``0.75``, and ``1.5``.
@@ -167,17 +165,21 @@ class VisualizerApp(QApplication):
 
         self.setPalette(dark_p)
 
-    def pause(self):
-        self.visualizer.pause()
+    def toggle_pause(self):
+        self.visualizer.toggle_pause()
 
     def seek_to(self, timestamp):
         self.visualizer.seek_to(timestamp)
 
-    def force_pause(self):
-        self.visualizer.force_pause()
+    def pause(self):
+        self.visualizer.pause()
 
-    def force_unpause(self):
-        self.visualizer.force_unpause()
+    def unpause(self):
+        self.visualizer.unpause()
 
     def save_as_image(self):
         return self.visualizer.grab().toImage()
+
+    # TODO remove in circlevis 2.0.0
+    force_pause = pause
+    force_unpause = unpause
